@@ -1,7 +1,9 @@
-package Kephra::Config::Default::Localisation;
+package Kephra::Config::Default::CommandList;
+use strict;
+use warnings;
+
 our $VERSION = '0.01';
 
-use strict;
 
 sub get {
 	return {
@@ -871,4 +873,4 @@ sub get {
 	},
 }
 
-1;
\ No newline at end of file
+1;
