@@ -1,9 +1,11 @@
 package Kephra::Config::Tree;
-$VERSION = '0.02';
+use strict;
+use warnings;
+
+our $VERSION = '0.02';
 
 # verbose config hash ops
 
-use strict;
 
 sub get_subtree { &subtree }
 sub subtree {
@@ -131,4 +133,4 @@ sub _convert_node_2_AoS {
 	}
 }
 
-1;
\ No newline at end of file
+1;
