@@ -1,5 +1,8 @@
 package Kephra::Edit::History;
-$VERSION = '0.02';
+use strict;
+use warnings;
+
+our $VERSION = '0.02';
 
 # undo, redo etc.
 
@@ -36,4 +39,4 @@ sub clear_history {
 sub can_undo  { _ep_ref()->CanUndo }
 sub can_redo  { _ep_ref()->CanRedo }
 
-1;
\ No newline at end of file
+1;
